@@ -4,8 +4,6 @@ import sys
 
 urlpatterns = []
 
-TEMPLATE_DEBUG = True
-
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
@@ -13,59 +11,38 @@ DATABASES = {
     }
 }
 
-
 INSTALLED_APPS = [
     'sekizai',
 ]
 
-TEMPLATE_DIRS = [
-    os.path.join(os.path.dirname(__file__), 'sekizai', 'test_templates'),
-]
-
-TEMPLATE_CONTEXT_PROCESSORS = [
-    'sekizai.context_processors.sekizai',
-]
-    
-
 ROOT_URLCONF = 'runtests'
 
-
 TEMPLATES = [
     {
         'BACKEND': 'django.template.backends.django.DjangoTemplates',
-        'DIRS': TEMPLATE_DIRS,
+        'DIRS': [os.path.join(os.path.dirname(__file__), 'sekizai', 'test_templates')],
         'OPTIONS': {
-            'context_processors': TEMPLATE_CONTEXT_PROCESSORS,
-            'debug': TEMPLATE_DEBUG
+            'context_processors': ['sekizai.context_processors.sekizai'],
+            'debug': True,
         },
     },
 ]
 
 
 def runtests():
-    from django import VERSION
+    from django import setup
     from django.conf import settings
-    if VERSION[0] == 1 and VERSION[1] < 6:
-        runner = 'django.test.simple.DjangoTestSuiteRunner'
-    else:
-        runner = 'django.test.runner.DiscoverRunner'
+    from django.test.utils import get_runner
     settings.configure(
         INSTALLED_APPS=INSTALLED_APPS,
         ROOT_URLCONF=ROOT_URLCONF,
         DATABASES=DATABASES,
-        TEST_RUNNER=runner,
-        TEMPLATE_DIRS=TEMPLATE_DIRS,
-        TEMPLATE_CONTEXT_PROCESSORS=TEMPLATE_CONTEXT_PROCESSORS,
-        TEMPLATE_DEBUG=TEMPLATE_DEBUG,
-        MIDDLEWARE_CLASSES=[],
+        TEST_RUNNER='django.test.runner.DiscoverRunner',
         TEMPLATES=TEMPLATES,
     )
-    if VERSION[1] >= 7:
-        from django import setup
-        setup()
+    setup()
 
     # Run the test suite, including the extra validation tests.
-    from django.test.utils import get_runner
     TestRunner = get_runner(settings)
 
     test_runner = TestRunner(verbosity=1, interactive=False, failfast=False)
